"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CalendarMultiSelect = exports.Calendar = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("@emotion/react");
const elements_1 = require("../elements");
const layout_1 = require("../layout");
const typography_1 = require("../typography");
const date_1 = require("../../functions/date");
const react_2 = require("react");
const theme_1 = require("../../../theme");
const DayButton = ({ value, disabled, onClick, isSelected, outsideRange, }) => ((0, jsx_runtime_1.jsx)(elements_1.Button, { onClick: onClick, disabled: outsideRange, opacity: outsideRange ? '0.5' : '1', p: "5px", borderRadius: "50%", backgroundColor: isSelected && !disabled ? theme_1.default.colors.primary : outsideRange ? theme_1.default.colors.borderGrey : 'white', width: "30px", height: "30px", alignContent: "center", children: (0, jsx_runtime_1.jsx)(typography_1.Text, { color: isSelected && !disabled ? 'white' : disabled ? theme_1.default.colors.lightGrey : 'black', textAlign: "center", children: value.toString() }) }));
// Single selection calendar
const Calendar = ({ date, minDate, maxDate, setDate, }) => {
    const [year, setYear] = (0, react_2.useState)(date.getFullYear());
    const [month, setMonth] = (0, react_2.useState)(date.getMonth());
    const [dayValuesState, setDayValues] = (0, react_2.useState)([]);
    const nextMonth = month === 11 ? 0 : month + 1;
    const prevMonth = month === 0 ? 11 : month - 1;
    const firstDayOfMonth = (0, date_1.getFirstDayOfMonth)(month, year);
    const lengthOfMonth = (0, date_1.getLengthOfMonth)(year, month);
    const lengthOfPrevMonth = (0, date_1.getLengthOfMonth)(year, prevMonth);
    const isOutsideRange = (index, d) => {
        const isInPrevMonth = index < firstDayOfMonth;
        const isInNextMonth = index > firstDayOfMonth + lengthOfMonth - 1;
        const isInNextYear = month === 11 && index > firstDayOfMonth + lengthOfMonth - 1;
        const isInPrevYear = month === 0 && index < firstDayOfMonth;
        const associatedMonth = isInPrevMonth ? prevMonth : isInNextMonth ? nextMonth : month;
        const associatedYear = isInPrevYear ? year - 1 : isInNextYear ? year + 1 : year;
        const associatedDate = new Date(associatedYear, associatedMonth, d);
        return (associatedDate.getTime() < (minDate || new Date(0, 0, 0)).getTime() ||
            associatedDate.getTime() > (maxDate || new Date(9999, 0, 0)).getTime());
    };
    const isPrevButtonDisabled = (0, react_2.useMemo)(() => {
        if (minDate) {
            return new Date(year, month, 1).getTime() < (minDate === null || minDate === void 0 ? void 0 : minDate.getTime());
        }
        return false;
    }, [month, year]);
    const isNextButtonDisabled = (0, react_2.useMemo)(() => {
        if (maxDate) {
            return new Date(year, month, lengthOfMonth).getTime() > (maxDate === null || maxDate === void 0 ? void 0 : maxDate.getTime());
        }
        return false;
    }, [month, year]);
    const handleDayClick = (day, outOfRange, index) => {
        if (!outOfRange && index < firstDayOfMonth) {
            setMonth(prevMonth);
            if (prevMonth === 11) {
                setYear(year - 1);
            }
        }
        else if (!outOfRange && index > firstDayOfMonth + lengthOfMonth - 1) {
            setMonth(nextMonth);
            if (nextMonth === 0) {
                setYear(year + 1);
            }
        }
        else {
            setDate(new Date(year, month, day));
        }
    };
    // Populate the dayValuesState array with the correct values for the current month
    (0, react_2.useEffect)(() => {
        const dayValues = [];
        for (let i = 0; i < firstDayOfMonth; i++) {
            dayValues.push(lengthOfPrevMonth - firstDayOfMonth + i + 1);
        }
        for (let i = 0; i < lengthOfMonth; i++) {
            dayValues.push(i + 1);
        }
        for (let i = 0; i < 42 - lengthOfMonth - firstDayOfMonth; i++) {
            dayValues.push(i + 1);
        }
        setDayValues(dayValues);
    }, [month, year]);
    return ((0, jsx_runtime_1.jsxs)(layout_1.Flex, { flexDirection: "column", justifyContent: "center", width: "100%", children: [(0, jsx_runtime_1.jsxs)(layout_1.Flex, { justifyContent: "space-between", mb: "10px", mx: "30px", children: [(0, jsx_runtime_1.jsx)(elements_1.Button, { onClick: () => {
                            if (prevMonth === 11) {
                                setYear(year - 1);
                            }
                            setMonth(prevMonth);
                        }, disabled: isPrevButtonDisabled, opacity: isPrevButtonDisabled ? '0.3' : '1', children: (0, jsx_runtime_1.jsx)(elements_1.Image, { border: theme_1.default.borders.standard1px, borderRadius: "50%", source: "icons/arrow-right-black.svg", alt: "<", overrideCss: (0, react_1.css) `
              transform: rotate(180deg);
            ` }) }), (0, jsx_runtime_1.jsx)(typography_1.Text, { fontWeight: "500", fontSize: "16px", children: `${date_1.monthLookup[month]} ${year}` }), (0, jsx_runtime_1.jsx)(elements_1.Button, { onClick: () => {
                            if (nextMonth === 0) {
                                setYear(year + 1);
                            }
                            setMonth(nextMonth);
                        }, disabled: isNextButtonDisabled, opacity: isNextButtonDisabled ? '0.3' : '1', children: (0, jsx_runtime_1.jsx)(elements_1.Image, { border: theme_1.default.borders.standard1px, borderRadius: "50%", source: "icons/arrow-right-black.svg", alt: ">" }) })] }), (0, jsx_runtime_1.jsxs)(layout_1.Grid, { gridTemplateColumns: "repeat(7, 1fr)", gridTemplateRows: "repeat(6, 1fr)", gridRowGap: "10px", ml: "25px", children: [date_1.dayLookup.map((d, index) => ((0, jsx_runtime_1.jsx)(typography_1.Text, { fontWeight: "bold", children: d.slice(0, 3) }, index))), dayValuesState.map((d, index) => {
                        const outOfRange = isOutsideRange(index, d);
                        return ((0, jsx_runtime_1.jsx)(DayButton, { outsideRange: outOfRange, value: d, onClick: () => handleDayClick(d, outOfRange, index), disabled: index < firstDayOfMonth || index > lengthOfMonth + firstDayOfMonth - 1, isSelected: new Date(year, month, d).getTime() === date.getTime() }, index));
                    })] })] }));
};
exports.Calendar = Calendar;
const CalendarMultiSelect = ({ date, minDate, maxDate, setDate, }) => {
    const [year, setYear] = (0, react_2.useState)(new Date().getFullYear());
    const [month, setMonth] = (0, react_2.useState)(new Date().getMonth());
    const [dayValuesState, setDayValues] = (0, react_2.useState)([]);
    const nextMonth = month === 11 ? 0 : month + 1;
    const prevMonth = month === 0 ? 11 : month - 1;
    const firstDayOfMonth = (0, date_1.getFirstDayOfMonth)(month, year);
    const lengthOfMonth = (0, date_1.getLengthOfMonth)(year, month);
    const lengthOfPrevMonth = (0, date_1.getLengthOfMonth)(year, prevMonth);
    const isOutsideRange = (index, d) => {
        const isInPrevMonth = index < firstDayOfMonth;
        const isInNextMonth = index > firstDayOfMonth + lengthOfMonth - 1;
        const isInNextYear = month === 11 && index > firstDayOfMonth + lengthOfMonth - 1;
        const isInPrevYear = month === 0 && index < firstDayOfMonth;
        const associatedMonth = isInPrevMonth ? prevMonth : isInNextMonth ? nextMonth : month;
        const associatedYear = isInPrevYear ? year - 1 : isInNextYear ? year + 1 : year;
        const associatedDate = new Date(associatedYear, associatedMonth, d);
        return (associatedDate.getTime() < (minDate || new Date(0, 0, 0)).getTime() ||
            associatedDate.getTime() > (maxDate || new Date(9999, 0, 0)).getTime());
    };
    const isPrevButtonDisabled = (0, react_2.useMemo)(() => {
        if (minDate) {
            return new Date(year, month, 1).getTime() < (minDate === null || minDate === void 0 ? void 0 : minDate.getTime());
        }
        return false;
    }, [month, year]);
    const isNextButtonDisabled = (0, react_2.useMemo)(() => {
        if (maxDate) {
            return new Date(year, month, lengthOfMonth).getTime() > (maxDate === null || maxDate === void 0 ? void 0 : maxDate.getTime());
        }
        return false;
    }, [month, year]);
    const handleDayClick = (day, outOfRange, index) => {
        if (!outOfRange && index < firstDayOfMonth) {
            setMonth(prevMonth);
            if (prevMonth === 11) {
                setYear(year - 1);
            }
        }
        else if (!outOfRange && index > firstDayOfMonth + lengthOfMonth - 1) {
            setMonth(nextMonth);
            if (nextMonth === 0) {
                setYear(year + 1);
            }
        }
        else {
            const newDate = new Date(year, month, day);
            const dateIndex = date.findIndex((x) => x.getTime() === newDate.getTime());
            if (dateIndex !== -1) {
                setDate(date.filter((x) => x.getTime() !== newDate.getTime()));
            }
            else {
                setDate([...date, newDate]);
            }
        }
    };
    // Populate the dayValuesState array with the correct values
    (0, react_2.useEffect)(() => {
        const dayValues = [];
        for (let i = 0; i < firstDayOfMonth; i++) {
            dayValues.push(lengthOfPrevMonth - firstDayOfMonth + i + 1);
        }
        for (let i = 0; i < lengthOfMonth; i++) {
            dayValues.push(i + 1);
        }
        for (let i = 0; i < 42 - lengthOfMonth - firstDayOfMonth; i++) {
            dayValues.push(i + 1);
        }
        setDayValues(dayValues);
    }, [month, year]);
    return ((0, jsx_runtime_1.jsxs)(layout_1.Flex, { flexDirection: "column", justifyContent: "center", width: "100%", children: [(0, jsx_runtime_1.jsxs)(layout_1.Flex, { justifyContent: "space-between", mb: "10px", mx: "30px", children: [(0, jsx_runtime_1.jsx)(elements_1.Button, { onClick: () => {
                            if (prevMonth === 11) {
                                setYear(year - 1);
                            }
                            setMonth(prevMonth);
                        }, disabled: isPrevButtonDisabled, opacity: isPrevButtonDisabled ? '0.3' : '1', children: (0, jsx_runtime_1.jsx)(elements_1.Image, { border: theme_1.default.borders.standard1px, borderRadius: "50%", source: "icons/arrow-right-black.svg", alt: "<", overrideCss: (0, react_1.css) `
              transform: rotate(180deg);
            ` }) }), (0, jsx_runtime_1.jsx)(typography_1.Text, { fontSize: "16px", fontWeight: "500", children: `${date_1.monthLookup[month]} ${year}` }), (0, jsx_runtime_1.jsx)(elements_1.Button, { onClick: () => {
                            if (nextMonth === 0) {
                                setYear(year + 1);
                            }
                            setMonth(nextMonth);
                        }, disabled: isNextButtonDisabled, opacity: isNextButtonDisabled ? '0.3' : '1', children: (0, jsx_runtime_1.jsx)(elements_1.Image, { border: theme_1.default.borders.standard1px, borderRadius: "50%", source: "icons/arrow-right-black.svg", alt: ">" }) })] }), (0, jsx_runtime_1.jsxs)(layout_1.Grid, { gridTemplateColumns: "repeat(7, 1fr)", gridTemplateRows: "repeat(6, 1fr)", gridRowGap: "10px", ml: "25px", children: [date_1.dayLookup.map((d, index) => ((0, jsx_runtime_1.jsx)(typography_1.Text, { fontWeight: "bold", children: d.slice(0, 3) }, index))), dayValuesState.map((d, index) => {
                        const outOfRange = isOutsideRange(index, d);
                        return ((0, jsx_runtime_1.jsx)(DayButton, { outsideRange: outOfRange, value: d, onClick: () => handleDayClick(d, outOfRange, index), disabled: index < firstDayOfMonth || index > lengthOfMonth + firstDayOfMonth - 1, isSelected: date.some((x) => x.getTime() === new Date(year, month, d).getTime()) }, index));
                    })] })] }));
};
exports.CalendarMultiSelect = CalendarMultiSelect;
