"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Checkbox = exports.InputField = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
/** @jsxImportSource @emotion/react */
const react_1 = require("react");
const react_2 = require("@emotion/react");
const theme_1 = require("../../../theme");
const typography_1 = require("../typography");
const form_1 = require("../../contexts/form");
const layout_1 = require("../layout");
const elements_1 = require("../elements");
const standard_css_1 = require("../../types/standard-css");
function InputField({ name, defaultValue, label, placeholder, overrideCss, required, disabled, value, pattern, type = 'text', validate, alwaysShowLabel, instructions, onChange, ...standardProps }) {
    const [valid, setValid] = (0, react_1.useState)({
        field: name,
        valid: true,
        message: '',
    });
    const { addError, removeError } = (0, form_1.useFormContext)();
    const [showLabel, setShowLabel] = (0, react_1.useState)(false);
    return ((0, jsx_runtime_1.jsxs)(layout_1.Flex, { position: "relative", flexDirection: "column", children: [(0, jsx_runtime_1.jsx)("label", { "data-test-id": `input-label-${name}`, css: (0, react_2.css) `
          font-size: 14px;
          position: absolute;
          top: -9px;
          left: 10px;
          background-color: white;
          padding: 0 10px;
          color: ${theme_1.default.colors.lightGrey};
          ${!showLabel &&
                    !alwaysShowLabel &&
                    (0, react_2.css) `
            display: none;
          `}
        `, children: label }), (0, jsx_runtime_1.jsx)("input", { value: value, defaultValue: defaultValue, onChange: (e) => {
                    if (e.target.value.includes('+27') && type === 'mobileNumber') {
                        e.target.value = e.target.value.replace('+27', '0');
                    }
                    onChange && onChange(e);
                    if (e.target.value !== '') {
                        setShowLabel(true);
                    }
                    else {
                        setShowLabel(false);
                    }
                    if (validate) {
                        const validation = validate(e);
                        setValid(validation);
                        if (validation.valid) {
                            removeError(validation);
                        }
                        else {
                            addError(validation);
                        }
                    }
                }, type: type, pattern: pattern, required: required, disabled: disabled, name: name, placeholder: placeholder, id: standardProps.id, className: standardProps.className || 'input-field', "data-test-id": standardProps.dataTestId || 'input-field', css: (0, react_2.css) `
          padding: 15px 16px;
          font-size: 16px;
          ${!valid.valid &&
                    (0, react_2.css) `
            border: 2px solid red;
          `}
          border: 1px solid ${theme_1.default.colors.lightGrey};
          color: #a8a8a8;
          background-color: transparent !important;
          border-radius: 5px;
          ${disabled &&
                    (0, react_2.css) `
            border: 1px solid ${theme_1.default.colors.lightGrey};
            color: #a8a8a8;
            background-color: ${theme_1.default.colors.backgroundGrey};
          `}
          ${(0, standard_css_1.default)(standardProps)}
          ${overrideCss}
        ` }), instructions && valid.valid && ((0, jsx_runtime_1.jsx)(typography_1.Text, { fontSize: "14px", opacity: "0.6", color: theme_1.default.colors.lightGrey, mt: "4px", dataTestId: `instruction-text-${name}`, children: instructions })), !valid.valid ? ((0, jsx_runtime_1.jsx)(typography_1.Text, { opacity: "0.6", color: "red", mt: "1px", dataTestId: `error-text-${name}`, children: valid.message })) : ((0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: showLabel && ((0, jsx_runtime_1.jsx)(elements_1.Image, { dataTestId: `image-valid-${name}`, source: "forms/green-tick.svg", alt: "valid", position: "absolute", top: "8%", right: "16px", width: "35px" })) }))] }));
}
exports.InputField = InputField;
const Checkbox = ({ name, label, overrideCss, disabled, required, onChange, checked, defaultChecked, ...standardProps }) => ((0, jsx_runtime_1.jsxs)(layout_1.Flex, { children: [(0, jsx_runtime_1.jsx)("input", { checked: checked, defaultChecked: defaultChecked, type: "checkbox", required: required, onChange: onChange, name: name, disabled: disabled, id: standardProps.id, className: standardProps.className || 'input-checkbox', "data-test-id": standardProps.dataTestId || 'input-checkbox', css: (0, react_2.css) `
        &:hover {
          cursor: pointer;
        }
        padding: 12px;
        margin-right: 10px;
        accent-color: ${theme_1.default.colors.primary};
        transform: scale(1.3);
        height: 20px;
        border: 2px solid ${theme_1.default.colors.borderGrey};
        color: #a8a8a8;
        border-radius: 5px;
        ${(0, standard_css_1.default)(standardProps)}
        ${overrideCss}
      ` }), (0, jsx_runtime_1.jsx)("label", { css: (0, react_2.css) `
        margin-top: 1px;
        font-size: 16px;
      `, children: label })] }));
exports.Checkbox = Checkbox;
